@@ -6,12 +6,26 @@ import scipy.optimize as sciopt
 from scipy.stats import norm
 
 import pytest
-from numpy.testing import (assert_, assert_almost_equal, assert_equal,
-                           assert_allclose)
+from numpy.testing import (
+    assert_,
+    assert_almost_equal,
+    assert_equal,
+    assert_allclose,
+)
 
-from refnx.analysis import (CurveFitter, Parameter, Parameters, Model,
-                            Objective, process_chain, load_chain, Bounds,
-                            PDF, autocorrelation_chain, integrated_time)
+from refnx.analysis import (
+    CurveFitter,
+    Parameter,
+    Parameters,
+    Model,
+    Objective,
+    process_chain,
+    load_chain,
+    Bounds,
+    PDF,
+    autocorrelation_chain,
+    integrated_time,
+)
 from refnx.analysis.curvefitter import _HAVE_PTSAMPLER, bounds_list
 from refnx.dataset import Data1D
 from refnx._lib import emcee
@@ -25,7 +39,6 @@ def line(x, params, *args, **kwds):
 
 
 class TestCurveFitter(object):
-
     def setup_method(self):
         # Reproducible results!
         np.random.seed(123)
@@ -46,26 +59,67 @@ class TestCurveFitter(object):
 
         self.data = Data1D(data=(x, y, y_err))
 
-        self.p = Parameter(self.b_ls, 'b', vary=True, bounds=(-100, 100))
-        self.p |= Parameter(self.m_ls, 'm', vary=True, bounds=(-100, 100))
+        self.p = Parameter(self.b_ls, "b", vary=True, bounds=(-100, 100))
+        self.p |= Parameter(self.m_ls, "m", vary=True, bounds=(-100, 100))
 
         self.model = Model(self.p, fitfunc=line)
         self.objective = Objective(self.model, self.data)
         assert_(len(self.objective.varying_parameters()) == 2)
 
-        mod = np.array([4.78166609, 4.42364699, 4.16404064, 3.50343504,
-                        3.4257084, 2.93594347, 2.92035638, 2.67533842,
-                        2.28136038, 2.19772983, 1.99295496, 1.93748334,
-                        1.87484436, 1.65161016, 1.44613461, 1.11128101,
-                        1.04584535, 0.86055984, 0.76913963, 0.73906649,
-                        0.73331407, 0.68350418, 0.65216599, 0.59838566,
-                        0.13070299, 0.10749131, -0.01010195, -0.10010155,
-                        -0.29495372, -0.42817431, -0.43122391, -0.64637715,
-                        -1.30560686, -1.32626428, -1.44835768, -1.52589881,
-                        -1.56371158, -2.12048349, -2.24899179, -2.50292682,
-                        -2.53576659, -2.55797996, -2.60870542, -2.7074727,
-                        -3.93781479, -4.12415366, -4.42313742, -4.98368609,
-                        -5.38782395, -5.44077086])
+        mod = np.array(
+            [
+                4.78166609,
+                4.42364699,
+                4.16404064,
+                3.50343504,
+                3.4257084,
+                2.93594347,
+                2.92035638,
+                2.67533842,
+                2.28136038,
+                2.19772983,
+                1.99295496,
+                1.93748334,
+                1.87484436,
+                1.65161016,
+                1.44613461,
+                1.11128101,
+                1.04584535,
+                0.86055984,
+                0.76913963,
+                0.73906649,
+                0.73331407,
+                0.68350418,
+                0.65216599,
+                0.59838566,
+                0.13070299,
+                0.10749131,
+                -0.01010195,
+                -0.10010155,
+                -0.29495372,
+                -0.42817431,
+                -0.43122391,
+                -0.64637715,
+                -1.30560686,
+                -1.32626428,
+                -1.44835768,
+                -1.52589881,
+                -1.56371158,
+                -2.12048349,
+                -2.24899179,
+                -2.50292682,
+                -2.53576659,
+                -2.55797996,
+                -2.60870542,
+                -2.7074727,
+                -3.93781479,
+                -4.12415366,
+                -4.42313742,
+                -4.98368609,
+                -5.38782395,
+                -5.44077086,
+            ]
+        )
         self.mod = mod
 
         self.mcfitter = CurveFitter(self.objective)
@@ -77,8 +131,9 @@ class TestCurveFitter(object):
         # try making a Parameter bound a normal distribution, then get an
         # approximation to box bounds
         self.p[0].bounds = PDF(norm(0, 1))
-        assert_allclose(bounds_list(self.p),
-                        [norm(0, 1).ppf([0.005, 0.995]), (-100, 100)])
+        assert_allclose(
+            bounds_list(self.p), [norm(0, 1).ppf([0.005, 0.995]), (-100, 100)]
+        )
 
     def test_constraints(self):
         # constraints should work during fitting
@@ -144,6 +199,7 @@ class TestCurveFitter(object):
         # if the number of parameters changes there should be an Exception
         # raised
         from pytest import raises
+
         with raises(RuntimeError):
             self.p[0].vary = False
             self.mcfitter.sample(1)
@@ -190,26 +246,26 @@ class TestCurveFitter(object):
         # smoke test for sampler initialisation
         # TODO check that the initialisation worked.
         # reproducible initialisation with random_state dependents
-        self.mcfitter.initialise('prior', random_state=1)
+        self.mcfitter.initialise("prior", random_state=1)
         starting_pos = np.copy(self.mcfitter._state.coords)
 
-        self.mcfitter.initialise('prior', random_state=1)
+        self.mcfitter.initialise("prior", random_state=1)
         starting_pos2 = self.mcfitter._state.coords
         assert_equal(starting_pos, starting_pos2)
 
-        self.mcfitter.initialise('jitter', random_state=1)
+        self.mcfitter.initialise("jitter", random_state=1)
         starting_pos = np.copy(self.mcfitter._state.coords)
 
-        self.mcfitter.initialise('jitter', random_state=1)
+        self.mcfitter.initialise("jitter", random_state=1)
         starting_pos2 = self.mcfitter._state.coords
         assert_equal(starting_pos, starting_pos2)
 
         mcfitter = CurveFitter(self.objective, nwalkers=100)
-        mcfitter.initialise('covar')
+        mcfitter.initialise("covar")
         assert_equal(mcfitter._state.coords.shape, (100, 2))
-        mcfitter.initialise('prior')
+        mcfitter.initialise("prior")
         assert_equal(mcfitter._state.coords.shape, (100, 2))
-        mcfitter.initialise('jitter')
+        mcfitter.initialise("jitter")
         assert_equal(mcfitter._state.coords.shape, (100, 2))
         # initialise with last position
         mcfitter.sample(steps=1)
@@ -229,11 +285,11 @@ class TestCurveFitter(object):
             return
         # initialise for Parallel tempering
         mcfitter = CurveFitter(self.objective, ntemps=20, nwalkers=100)
-        mcfitter.initialise('covar')
+        mcfitter.initialise("covar")
         assert_equal(mcfitter._state.coords.shape, (20, 100, 2))
-        mcfitter.initialise('prior')
+        mcfitter.initialise("prior")
         assert_equal(mcfitter._state.coords.shape, (20, 100, 2))
-        mcfitter.initialise('jitter')
+        mcfitter.initialise("jitter")
         assert_equal(mcfitter._state.coords.shape, (20, 100, 2))
         # initialise with last position
         mcfitter.sample(steps=1)
@@ -265,25 +321,30 @@ class TestCurveFitter(object):
         res0 = self.mcfitter.fit(verbose=False, callback=callback)
 
         # least_squares
-        res1 = self.mcfitter.fit(method='least_squares')
+        res1 = self.mcfitter.fit(method="least_squares")
         assert_almost_equal(res1.x, [self.b_ls, self.m_ls], 6)
 
         # least_squares doesn't accept a callback. As well as testing that
         # least_squares works, it checks that providing a callback doesn't
         # trip the fitter up.
-        res1 = self.mcfitter.fit(method='least_squares', callback=callback)
+        res1 = self.mcfitter.fit(method="least_squares", callback=callback)
         assert_almost_equal(res1.x, [self.b_ls, self.m_ls], 6)
 
         # need full bounds for differential_evolution
         self.p[0].range(3, 7)
         self.p[1].range(-2, 0)
-        res2 = self.mcfitter.fit(method='differential_evolution', seed=1,
-                                 popsize=10, maxiter=100, callback=callback2)
+        res2 = self.mcfitter.fit(
+            method="differential_evolution",
+            seed=1,
+            popsize=10,
+            maxiter=100,
+            callback=callback2,
+        )
         assert_almost_equal(res2.x, [self.b_ls, self.m_ls], 6)
 
         # check that the res object has covar and stderr
-        assert_('covar' in res0)
-        assert_('stderr' in res0)
+        assert_("covar" in res0)
+        assert_("stderr" in res0)
 
     def test_NIST(self):
         # Run all the NIST standard tests with leastsq
@@ -297,7 +358,7 @@ class TestCurveFitter(object):
 
 def gauss(x, p0):
     p = np.array(p0)
-    return p[0] + p[1] * np.exp(-((x - p[2]) / p[3])**2)
+    return p[0] + p[1] * np.exp(-(((x - p[2]) / p[3]) ** 2))
 
 
 class TestFitterGauss(object):
@@ -309,7 +370,7 @@ class TestFitterGauss(object):
         self.path = os.path.dirname(os.path.abspath(__file__))
         self.tmpdir = tmpdir.strpath
 
-        theoretical = np.loadtxt(os.path.join(self.path, 'gauss_data.txt'))
+        theoretical = np.loadtxt(os.path.join(self.path, "gauss_data.txt"))
         xvals, yvals, evals = np.hsplit(theoretical, 3)
         xvals = xvals.flatten()
         yvals = yvals.flatten()
@@ -318,22 +379,34 @@ class TestFitterGauss(object):
         # these best weighted values and uncertainties obtained with Igor
         self.best_weighted = [-0.00246095, 19.5299, -8.28446e-2, 1.24692]
 
-        self.best_weighted_errors = [0.0220313708486, 1.12879436221,
-                                     0.0447659158681, 0.0412022938883]
+        self.best_weighted_errors = [
+            0.0220313708486,
+            1.12879436221,
+            0.0447659158681,
+            0.0412022938883,
+        ]
 
         self.best_weighted_chisqr = 77.6040960351
 
-        self.best_unweighted = [-0.10584111872702096, 19.240347049328989,
-                                0.0092623066070940396, 1.501362314145845]
+        self.best_unweighted = [
+            -0.10584111872702096,
+            19.240347049328989,
+            0.0092623066070940396,
+            1.501362314145845,
+        ]
 
-        self.best_unweighted_errors = [0.34246565477, 0.689820935208,
-                                       0.0411243173041, 0.0693429375282]
+        self.best_unweighted_errors = [
+            0.34246565477,
+            0.689820935208,
+            0.0411243173041,
+            0.0693429375282,
+        ]
 
         self.best_unweighted_chisqr = 497.102084956
 
-        self.p0 = np.array([0.1, 20., 0.1, 0.1])
-        self.names = ['bkg', 'A', 'x0', 'width']
-        self.bounds = [(-1, 1), (0, 30), (-5., 5.), (0.001, 2)]
+        self.p0 = np.array([0.1, 20.0, 0.1, 0.1])
+        self.names = ["bkg", "A", "x0", "width"]
+        self.bounds = [(-1, 1), (0, 30), (-5.0, 5.0), (0.001, 2)]
 
         self.params = Parameters(name="gauss_params")
         for p, name, bound in zip(self.p0, self.names, self.bounds):
@@ -359,12 +432,13 @@ class TestFitterGauss(object):
         self.objective.setp(self.p0)
 
         f = CurveFitter(self.objective, nwalkers=100)
-        res = f.fit('least_squares', jac='3-point')
+        res = f.fit("least_squares", jac="3-point")
 
         output = res.x
         assert_almost_equal(output, self.best_weighted, 3)
-        assert_almost_equal(self.objective.chisqr(),
-                            self.best_weighted_chisqr, 5)
+        assert_almost_equal(
+            self.objective.chisqr(), self.best_weighted_chisqr, 5
+        )
 
         # compare the residuals
         res = (self.data.y - self.model(self.data.x)) / self.data.y_err
@@ -375,7 +449,7 @@ class TestFitterGauss(object):
         assert_allclose(uncertainties, self.best_weighted_errors, rtol=0.005)
 
         # we're also going to try the checkpointing here.
-        checkpoint = os.path.join(self.tmpdir, 'checkpoint.txt')
+        checkpoint = os.path.join(self.tmpdir, "checkpoint.txt")
 
         # compare samples to best_weighted_errors
         np.random.seed(1)
@@ -393,7 +467,7 @@ class TestFitterGauss(object):
         chain = load_chain(checkpoint)
         assert_allclose(chain, f.chain)
 
-        f.initialise('jitter')
+        f.initialise("jitter")
         f.sample(steps=2, nthin=4, f=checkpoint, verbose=False)
         assert_equal(f.chain.shape[0], 2)
 
@@ -409,7 +483,7 @@ class TestFitterGauss(object):
         # being varied.
         self.params[0].vary = False
         f = CurveFitter(self.objective, nwalkers=100)
-        f.initialise('jitter')
+        f.initialise("jitter")
         f.sample(steps=2, nthin=4, f=checkpoint, verbose=False)
         g = self.objective.pgen(ngen=100)
         pvec = next(g)
@@ -426,8 +500,9 @@ class TestFitterGauss(object):
         res = f.fit()
 
         output = res.x
-        assert_almost_equal(self.objective.chisqr(),
-                            self.best_unweighted_chisqr)
+        assert_almost_equal(
+            self.objective.chisqr(), self.best_unweighted_chisqr
+        )
         assert_almost_equal(output, self.best_unweighted, 5)
 
         # compare the residuals
@@ -448,11 +523,11 @@ class TestFitterGauss(object):
         """test minimisers against the Gaussian fit"""
         f = CurveFitter(self.objective)
 
-        methods = ['differential_evolution', 'L-BFGS-B', 'least_squares']
-        if hasattr(sciopt, 'shgo'):
-            methods.append('shgo')
-        if hasattr(sciopt, 'dual_annealing'):
-            methods.append('dual_annealing')
+        methods = ["differential_evolution", "L-BFGS-B", "least_squares"]
+        if hasattr(sciopt, "shgo"):
+            methods.append("shgo")
+        if hasattr(sciopt, "dual_annealing"):
+            methods.append("dual_annealing")
 
         for method in methods:
             self.objective.setp(self.p0)
@@ -464,10 +539,11 @@ class TestFitterGauss(object):
         logp0 = self.objective.logp()
 
         # check that probabilities are calculated correctly
-        assert_allclose(self.objective.logpost(),
-                        self.objective.logp() + self.objective.logl())
-        assert_allclose(self.objective.nlpost(),
-                        -self.objective.logpost())
+        assert_allclose(
+            self.objective.logpost(),
+            self.objective.logp() + self.objective.logl(),
+        )
+        assert_allclose(self.objective.nlpost(), -self.objective.logpost())
 
         # if the priors are all uniform then the only difference between
         # logpost and logl is a constant. A minimiser should converge on the
@@ -475,13 +551,13 @@ class TestFitterGauss(object):
         # The test works for dual_annealing, but not for differential
         # evolution, not sure why that is.
         self.objective.setp(self.p0)
-        res1 = f.fit(method='dual_annealing', seed=1)
+        res1 = f.fit(method="dual_annealing", seed=1)
         assert_almost_equal(res1.x, self.best_weighted, 3)
         nll1 = self.objective.nll()
         nlpost1 = self.objective.nlpost()
 
         self.objective.setp(self.p0)
-        res2 = f.fit(method='dual_annealing', target='nlpost', seed=1)
+        res2 = f.fit(method="dual_annealing", target="nlpost", seed=1)
         assert_almost_equal(res2.x, self.best_weighted, 3)
         nll2 = self.objective.nll()
         nlpost2 = self.objective.nlpost()
